@@ -2,9 +2,6 @@ from datetime import datetime
 import sys
 import os
 
-from constants import ORDER_SIDE, Side
-
-
 
 #没有融券
 def decode_atx_side(side):
@@ -32,11 +29,11 @@ def side_to_target_type(side):
         target_type = "sell"
     return target_type
 
-def decode_exchange_id(exchange):
+def decode_exchange_id(str_exchange):
     exchange = 0
-    if exchange == 'SH':
+    if str_exchange == 'SH':
         exchange = 101        #EXCHANGE_SSE 
-    elif exchange == 'SZ':
+    elif str_exchange == 'SZ':
         exchange = 102        #EXCHANGE_SZE 
     
     return exchange
@@ -53,7 +50,7 @@ def get_log_default_path():
     return dirs
 
 def get_today_date():
-    return datetime.today().stratxime('%Y-%m-%d')
+    return datetime.today().strftime('%Y-%m-%d')
 
 def get_digit_from_env(env_name, default_num):
     num = str(os.environ.get(env_name))
@@ -61,4 +58,25 @@ def get_digit_from_env(env_name, default_num):
 
 def get_log_given_path(path):
     dirs = os.path.join(path)
-    return path
\ No newline at end of file
+    return path
+
+def decode_ordtype(order_type:str):
+    ord_type = -1
+    mapping = {
+        'kf_twap_plus': 101,
+        'kf_vwap_plus': 102,
+        'kf_twap_core': 103,
+        'kf_vwap_core': 104,
+        'kf_pov_core': 105,
+        'kf_t0': 106,
+        'kf_passthru': 201,
+        'ft_vwap_ai': 202,
+        'ft_twap_ai': 203,
+        'ft_vwap_ai_plus': 204,
+        'ft_twap_ai_plus': 205,
+        'hx_twap': 206,
+        'hx_vwap': 207
+    }
+    ord_type = mapping.get(order_type, -1)
+    return ord_type
+
